<?php
/**
 * VendorFuel functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package VendorFuel
 */

if ( ! defined( 'VENDORFUEL_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'VENDORFUEL_VERSION', '1.0.0' );
}

if ( ! function_exists( 'vendorfuel_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function vendorfuel_setup() {
		add_theme_support( 'align-wide' );
		add_theme_support( 'wp-block-styles' );

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on VendorFuel, use a find and replace
		 * to change 'vendorfuel' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'vendorfuel', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'primary-menu'  => esc_html__( 'Primary', 'vendorfuel' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'vendorfuel_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);

		/**
		 * Add support for editor color palette presets.
		 */
		add_theme_support(
			'editor-color-palette',
			array(
				array(
					'name'  => esc_attr__( 'Red', 'vendorfuel' ),
					'slug'  => 'red',
					'color' => '#ed3530',
				),
				array(
					'name'  => esc_attr__( 'Orange', 'vendorfuel' ),
					'slug'  => 'orange',
					'color' => '#f37324',
				),
				array(
					'name'  => esc_attr__( 'Brown', 'vendorfuel' ),
					'slug'  => 'brown',
					'color' => '#bf5223',
				),
				array(
					'name'  => esc_attr__( 'Light Green', 'vendorfuel' ),
					'slug'  => 'light-green',
					'color' => '#9ba761',
				),
				array(
					'name'  => esc_attr__( 'Dark Green', 'vendorfuel' ),
					'slug'  => 'dark-green',
					'color' => '#014628',
				),
				array(
					'name'  => esc_attr__( 'Light Blue', 'vendorfuel' ),
					'slug'  => 'light-blue',
					'color' => '#00a4e0',
				),
				array(
					'name'  => esc_attr__( 'Dark Blue', 'vendorfuel' ),
					'slug'  => 'dark-blue',
					'color' => '#003b59',
				),
				array(
					'name'  => esc_attr__( 'Warm Gray', 'vendorfuel' ),
					'slug'  => 'warm-gray',
					'color' => '#7c6a55',
				),
				array(
					'name'  => esc_attr__( 'White', 'vendorfuel' ),
					'slug'  => 'white',
					'color' => '#fff',
				),
				array(
					'name'  => esc_attr__( 'Black', 'vendorfuel' ),
					'slug'  => 'black',
					'color' => '#000',
				),
			) 
		);
		
		/**
		 * Add support for editor gradient presets.
		 */
		add_theme_support(
			'editor-gradient-presets',
			array(
				array(
					'name'     => esc_attr__( 'Red to Orange', 'vendorfuel' ),
					'gradient' => 'linear-gradient(135deg, #ed3530 0%, #f37324 100%)',
					'slug'     => 'red-to-orange',
				),
				array(
					'name'     => esc_attr__( 'Light to Dark Green', 'vendorfuel' ),
					'gradient' => 'linear-gradient(135deg, #9ba761 0%, #014628 100%)',
					'slug'     => 'light-to-dark-green',
				),
				array(
					'name'     => esc_attr__( 'Light to Dark Blue', 'vendorfuel' ),
					'gradient' => 'linear-gradient(135deg, #00a4e0 0%, #003b59 100%)',
					'slug'     => 'light-to-dark-blue',
				),
			)
		);      
	}
endif;
add_action( 'after_setup_theme', 'vendorfuel_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function vendorfuel_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'vendorfuel_content_width', 640 );
}
add_action( 'after_setup_theme', 'vendorfuel_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function vendorfuel_widgets_init() {
	register_sidebar(
		array(
			'name'           => esc_html__( 'Sidebar', 'vendorfuel' ),
			'id'             => 'sidebar-1',
			'description'    => esc_html__( 'Appears just above the footer.', 'vendorfuel' ),
			'before_sidebar' => '<div class="row row-cols-1 row-cols-md-2 row-cols-lg-3 g-3">',
			'after_sidebar'  => '</div>',
			'before_widget'  => '<section id="%1$s" class="widget col %2$s"><div class="card h-100"><div class="card-body">',
			'after_widget'   => '</div></div></section>',
			'before_title'   => '<h2 class="widget-title h6 card-title">',
			'after_title'    => '</h2>',
		)
	);
	register_sidebar(
		array(
			'name'           => esc_html__( 'Footer', 'vendorfuel' ),
			'id'             => 'sidebar-2',
			'description'    => esc_html__( 'Widget area within footer.', 'vendorfuel' ),
			'before_sidebar' => '<div class="row row-cols-1 row-cols-md-2 row-cols-lg-3">',
			'after_sidebar'  => '</div>',
			'before_widget'  => '<section id="%1$s" class="widget col %2$s">',
			'after_widget'   => '</section>',
			'before_title'   => '<h2 class="widget-title h6">',
			'after_title'    => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'vendorfuel_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function vendorfuel_scripts() {
	// Dequeue deprecated VendorFuel Branding settings.
	if ( wp_style_is( 'vendorfuel-theme-css' ) ) {
		wp_dequeue_style( 'vendorfuel-theme-css' );
	}

	// Load only one version of Bootstrap.
	if ( wp_style_is( 'bootstrap-css' ) ) {
		wp_dequeue_style( 'bootstrap-css' );
	}
	if ( wp_script_is( 'bootstrap' ) ) {
		wp_dequeue_script( 'bootstrap' );
	}

	// Enqueue Bootstrap.
	wp_enqueue_style(
		'bootstrap-style',
		get_template_directory_uri() . '/assets/css/bootstrap/bootstrap.min.css',
		array(),
		'4.6.0'
	);
	wp_enqueue_script(
		'bootstrap-script',
		get_template_directory_uri() . '/assets/js/bootstrap/bootstrap.bundle.min.js',
		array( 'jquery' ),
		'4.6.0',
		true
	);

	// Enqueue Bootstrap icons.
	if ( ! wp_style_is( 'bootstrap-icons' ) ) {
		wp_enqueue_style(
			'bootstrap-icons',
			get_template_directory_uri() . '/assets/css/bootstrap-icons/bootstrap-icons.css',
			array(),
			'1.4.1'
		);
	}

	wp_enqueue_style( 
		'vendorfuel-style',
		get_stylesheet_uri(),
		array( 'bootstrap-style' ), 
		VENDORFUEL_VERSION 
	);
	wp_style_add_data( 'vendorfuel-style', 'rtl', 'replace' );

	// Enqueue theme VendorFuel components.
	wp_enqueue_script( 
		'vendorfuel-theme-script', 
		get_template_directory_uri() . '/build/index.js', 
		array( 'vendorfuel-local-controllers' ), 
		VENDORFUEL_VERSION,
		true 
	);

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'vendorfuel_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load WP Bootstrap Nav Walkers
 */
require get_template_directory() . '/inc/class-vendorfuel-nav-walker.php';
require get_template_directory() . '/inc/class-vendorfuel-side-nav-walker.php';
